#include "Animation/AnimationController.h"

AnimationController::AnimationController(Fader *fader)
    : m_fader(fader), m_animation(nullptr), m_frame(0)
{}

void AnimationController::changeAnimation(std::unique_ptr<Animation> anim, bool transition)
{
    if(transition && m_animation) {
        m_nextAnimation = std::move(anim);
        m_animation->stop();
    } else {
        m_frame = 0;

        m_animation = std::move(anim);
        m_nextAnimation.reset(nullptr);
    }
}

void AnimationController::loop(void)
{
    if(m_animation && !m_animation->finished()) {
        m_animation->loop(m_frame);
    }

    m_frame++;

    if(m_nextAnimation &&
        (!m_animation || m_animation->finished())) {
        // old animation has finished or is unset -> start the new one
        m_frame = 0;
        m_animation.swap(m_nextAnimation);
        m_nextAnimation.reset(nullptr);
    }
}

void AnimationController::restart(void)
{
    m_animation->reset();
    m_frame = 0;
}
